@@ -8,15 +8,13 @@ from abc import ABC, abstractmethod
 
 
 class ConfigurationNotFound(FileNotFoundError):
-    """Exception raised when configuration can't be found
-    """
+    """Exception raised when configuration can't be found"""
 
     pass
 
 
 class ConfigStoreBase(ABC, Base):
-    """Abstract base class for configuration store plugins
-    """
+    """Abstract base class for configuration store plugins"""
 
     ALLOWED_CONFIG_NAME = r"^[a-zA-Z0-9_-]+(\.[a-zA-Z0-9_-]+)*$"
 
@@ -30,5 +28,4 @@ class ConfigStoreBase(ABC, Base):
         """
 
         if not re.match(self.ALLOWED_CONFIG_NAME, name):
-            self.statsd.get_counter().increment("invalid_config_name")
             raise NameError
