@@ -2,6 +2,7 @@
 #
 # SPDX-License-Identifier: EUPL-1.2
 
+import json
 import minty
 from ..infrastructure import InfrastructureFactory
 from ..repository import RepositoryBase, RepositoryFactory
@@ -9,7 +10,17 @@ from .events import Event, EventService, event
 from abc import ABC, abstractmethod
 from copy import copy
 from functools import partial
-from typing import Any, Dict, Iterable, List, Protocol, Set, Type, TypedDict
+from typing import (
+    Any,
+    Dict,
+    Iterable,
+    List,
+    Optional,
+    Protocol,
+    Set,
+    Type,
+    TypedDict,
+)
 from uuid import UUID
 
 __all__ = [
@@ -42,6 +53,15 @@ class UserInfo:
         self.user_uuid = user_uuid
         self.permissions = permissions
 
+    def json(self):
+        return json.dumps(
+            {
+                "type": "UserInfo",
+                "user_uuid": str(self.user_uuid),
+                "permissions": self.permissions,
+            }
+        )
+
 
 class SplitCommandBase(minty.Base, ABC):
     """
@@ -263,6 +283,8 @@ class DomainQueryContainer:
 class CommandBase(minty.Base, ABC):
     "Base class for 'command' parts of domains"
 
+    user_info: Optional[UserInfo]
+
     def __init__(
         self,
         repository_factory: RepositoryFactory,
@@ -294,6 +316,8 @@ class CommandBase(minty.Base, ABC):
 class QueryBase(minty.Base, ABC):
     "Base class for 'query' parts of domains"
 
+    user_info: Optional[UserInfo]
+
     def __init__(self, repository_factory, context, user_uuid: UUID):
         self.repository_factory = repository_factory
         self.context = context
@@ -687,16 +711,20 @@ class CQRS(minty.Base):
             }
 
     def get_query_instance(
-        self, correlation_id: UUID, domain: str, context: str, user_uuid: UUID
+        self,
+        correlation_id: UUID,
+        domain: str,
+        context: str,
+        user_uuid: UUID,
+        user_info: Optional[UserInfo] = None,
     ):
-        """Instantiate and return the "query" part of the specified domain.
+        """
+        Instantiate and return the "query" part of the specified domain.
 
         :param domain: name of the domain to get the query instance for
-        :type domain: str
         :param context: context for this query instance
-        :type context: str
-        :param user_uuid: UUID of the user that's going to execute commands
-        :type user_uuid: uuid
+        :param user_uuid: UUID of the user that's doing queries
+        :param user_info: UserInfo object representing the user doing queries
         """
 
         self.logger.debug(
@@ -711,6 +739,8 @@ class CQRS(minty.Base):
             context=context,
             user_uuid=user_uuid,
         )
+        # TODO pass user_info in parameters to `get_query_instance`
+        query_instance.user_info = user_info
 
         initialized_middleware = []
 
@@ -739,9 +769,15 @@ class CQRS(minty.Base):
         return wrapped_query
 
     def get_command_instance(
-        self, correlation_id: UUID, domain: str, context: str, user_uuid: UUID
+        self,
+        correlation_id: UUID,
+        domain: str,
+        context: str,
+        user_uuid: UUID,
+        user_info: Optional[UserInfo] = None,
     ):
-        """Instantiate and return the "command" instance of the specified domain.
+        """
+        Instantiate and return the "command" instance of the specified domain.
 
         Command instance is instantiated with optional layers of middleware to handle
         various functions when executing a command. `InfrastructureStateManager` is
@@ -750,11 +786,9 @@ class CQRS(minty.Base):
         :param correlation_id: unique identifier for the current chain of
             events.
         :param domain: name of the domain to get the query instance for
-        :type domain: str
         :param context: context for this command instance
-        :type context: str
         :param user_uuid: UUID of the user that's going to execute commands
-        :type user_uuid: uuid
+        :param user_info: UserInfo object representing the user executing commands
         """
         self.logger.debug(
             f"Creating command instance for domain '{domain}' with context "
@@ -768,6 +802,7 @@ class CQRS(minty.Base):
             domain=domain,
             context=context,
             user_uuid=user_uuid,
+            user_info=user_info,
         )
 
         cmd_instance = self.domains[domain]["module"].get_command_instance(
@@ -776,6 +811,8 @@ class CQRS(minty.Base):
             user_uuid=user_uuid,
             event_service=event_service,
         )
+        # TODO pass user_info in parameters to `get_command_instance`
+        cmd_instance.user_info = user_info
 
         cmd_wrapped = CommandWrapper(
             command_instance=cmd_instance, domain=short_domain
